Skip to contents

Samples randomly selected from a single population are tested by one 2-state fallible reference test and a 2-state experimental test.

Usage

data1

Format

A data frame with four rows and three variables:

  • exp_result: result of experimental test (positive, negative).

  • ref1_result: result of reference test (positive, negative).

  • count: number of samples with the unique testing combination.