Data set for Example 3 in vignette "DiagTestKit Examples"
data3.RdSamples randomly selected from single population tested by one 3-state fallible reference test and a 2-state experimental test.

data3.RdSamples randomly selected from single population tested by one 3-state fallible reference test and a 2-state experimental test.