Data set for Example 1 in vignette "DiagTestKit Examples"
data1.RdSamples randomly selected from a single population are tested by one 2-state fallible reference test and a 2-state experimental test.

data1.RdSamples randomly selected from a single population are tested by one 2-state fallible reference test and a 2-state experimental test.